==> bow-0.2-sources.jar: org/chorem/bow/UserMigration.java <==
/*
 * #%L
 * bow
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2010 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.chorem.bow;

import java.security.NoSuchAlgorithmException;
import java.util.ArrayList;
import java.util.List;
import java.util.Set;
import org.nuiton.util.StringUtil;
import org.nuiton.wikitty.Wikitty;
import org.nuiton.wikitty.WikittyException;
import org.nuiton.wikitty.WikittyExtension;
import org.nuiton.wikitty.WikittyExtensionMigration;
import org.nuiton.wikitty.WikittyService;
import org.nuiton.wikitty.WikittyTransaction;

/**
 *
 * @author sherkhan
 */
public class UserMigration implements WikittyExtensionMigration {

    @Override
    public Wikitty migrate(WikittyService service, WikittyTransaction transaction, Wikitty wikitty, WikittyExtension oldExt, WikittyExtension newExt) {

        String id = wikitty.getId();
        String version = wikitty.getVersion();
        Wikitty newWikitty = new Wikitty(id);
        newWikitty.setVersion(version);

        List<WikittyExtension> extensions = new ArrayList<WikittyExtension>(wikitty.getExtensions());
        if (extensions.contains(oldExt)) {
            extensions.remove(oldExt);
            extensions.add(newExt);
        }
        newWikitty.addExtension(extensions);

        Set<String> fieldNames = wikitty.fieldNames();
        for (String fieldName : fieldNames) {
            Object obj = wikitty.getFqField(fieldName);
            if (fieldName.equals("User.password")) {
                String password = (String) obj;
                try {
                    password = StringUtil.encodeMD5(password);
                } catch (NoSuchAlgorithmException ex) {
                    throw new WikittyException(ex);
                }
                obj = password;
            }
            newWikitty.setFqField(fieldName, obj);
        }

        return newWikitty;
    }
}

==> bow-0.3-sources.jar: org/chorem/bow/UserMigration.java <==
/*
 * #%L
 * bow
 * 
 * $Id: UserMigration.java 144 2010-12-23 10:24:48Z bpoussin $
 * $HeadURL: http://svn.chorem.org/svn/bow/tags/bow-0.3/src/main/java/org/chorem/bow/UserMigration.java $
 * %%
 * Copyright (C) 2010 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.chorem.bow;

import java.util.ArrayList;
import java.util.List;
import java.util.Set;
import org.nuiton.util.StringUtil;
import org.nuiton.wikitty.Wikitty;
import org.nuiton.wikitty.WikittyException;
import org.nuiton.wikitty.WikittyExtension;
import org.nuiton.wikitty.WikittyExtensionMigration;
import org.nuiton.wikitty.WikittyService;
import org.nuiton.wikitty.WikittyTransaction;

/**
 *
 * @author sherkhan
 */
public class UserMigration implements WikittyExtensionMigration {

    @Override
    public Wikitty migrate(WikittyService service,
                           WikittyTransaction transaction,
                           Wikitty wikitty,
                           WikittyExtension oldExt,
                           WikittyExtension newExt) {

        String id = wikitty.getId();
        String version = wikitty.getVersion();
        Wikitty newWikitty = new Wikitty(id);
        newWikitty.setVersion(version);

        List<WikittyExtension> extensions =
                new ArrayList<WikittyExtension>(wikitty.getExtensions());
        if (extensions.contains(oldExt)) {
            extensions.remove(oldExt);
            extensions.add(newExt);
        }
        newWikitty.addExtension(extensions);

        Set<String> fieldNames = wikitty.fieldNames();
        for (String fieldName : fieldNames) {
            Object obj = wikitty.getFqField(fieldName);
            if (fieldName.equals("User.password")) {
                String password = (String) obj;
                try {
                    password = StringUtil.encodeMD5(password);
                } catch (RuntimeException ex) {
                    throw new WikittyException("Could not encode password", ex);
                }
                obj = password;
            }
            newWikitty.setFqField(fieldName, obj);
        }

        return newWikitty;
    }
}
